# eric7.Debugger.VariablesFilterDialog

Module implementing the variables filter dialog.

### Global Attributes

None

### Classes

VariablesFilterDialog | Class implementing the variables filter dialog.

### Functions

None

## VariablesFilterDialog

Class implementing the variables filter dialog.

It opens a dialog window for the configuration of the variables type filters to be applied during a debugging session. Pressing 'Apply' will show the effect of the current selection on the currently shown variables. 'Reset' will reset the selection to the one the dialog was opened with.

### Signals

applyFilterLists(list of str, list of str)
  emitted to apply the given locals and globals filters to the currently shown variables

### Derived from

QDialog, Ui_VariablesFilterDialog

### Class Attributes

None

### Class Methods

None

### Methods

VariablesFilterDialog | Constructor
getSelection | Public slot to retrieve the current selections.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
setSelection | Public slot to set the current selection.

### Static Methods

None

#### VariablesFilterDialog (Constructor)

VariablesFilterDialog(parent=None, name=None, modal=False)

Constructor

parent
  parent widget of this dialog (QWidget)
name
  name of this dialog (string)
modal
  flag to indicate a modal dialog (boolean)

#### VariablesFilterDialog.getSelection

getSelection()

Public slot to retrieve the current selections.

Return:
  tuple of lists containing the variable filters. The first list is the locals variables filter, the second the globals variables filter.

Return Type:
  tuple of (list of str, list of str)

#### VariablesFilterDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### VariablesFilterDialog.setSelection

setSelection(lList, gList)

Public slot to set the current selection.

lList (list of str)
  local variables filter
gList (list of str)
  global variables filter

Up